Crate rustpython_common

Crate rustpython_common 

A crate to hold types and functions common to all rustpython components.

Re-exports

pub use rustpython_wtf8 as wtf8;

Modules

atomic
borrow
boxvec
An unresizable vector backed by a Box<[T]>
cformat
Implementation of Printf-Style string formatting as per the Python Docs.
encodings
float_ops
format
hash
int
linked_list
This module is modified from tokio::util::linked_list: https://github.com/tokio-rs/tokio/blob/master/tokio/src/util/linked_list.rs Tokio is licensed under the MIT license:
lock
A module containing lock_api-based lock types that are or are not Send + Sync depending on whether the threading feature of this module is enabled.
rand
rc
refcount
static_cell
str
vendored
wtf8_index
Random access into a WTF-8 buffer.

Macros

ascii
Creates an AsciiStr from a string literal, throwing a compile error if the literal isn’t actually ascii.
static_cell