pub enum CFormatType {
Number(CNumberType),
Float(CFloatType),
Character(CCharacterType),
String(CFormatConversion),
Bytes,
Unsupported {
ch: CodePoint,
index: usize,
},
}Variants
Number(CNumberType)
Float(CFloatType)
Character(CCharacterType)
String(CFormatConversion)
Bytes
Unsupported
Parsed conversion that is not one of the supported specifiers. The argument is still consumed, then formatting raises ValueError.
Implementations