UTF-7 encode / incremental decode.
Constants
Functions
- decode
- Incremental UTF-7 decode.
- encode
- encode_
bytes - Encode
sas UTF-7. Every code point is representable, so this cannot fail.
UTF-7 encode / incremental decode.
s as UTF-7. Every code point is representable, so this cannot fail.