pub enum HexFloatError {
Invalid,
TooLong,
Overflow,
}Expand description
Error from from_hex, mapping to the exception the caller should raise.
Variants
Invalid
ValueError “invalid hexadecimal floating-point string”
TooLong
ValueError “hexadecimal string too long to convert”
Overflow
OverflowError “hexadecimal value too large to represent as a float”