pub struct FormatSpec { /* private fields */ }Implementations
Sourceimpl FormatSpec
impl FormatSpec
pub fn parse(text: impl AsRef<Wtf8>) -> Result<Self, FormatSpecError>
Sourcepub fn has_locale_format(&self) -> bool
pub fn has_locale_format(&self) -> bool
Returns true if this format spec uses the locale-aware ‘n’ format type.
Sourcepub fn is_decimal_int_format(&self) -> bool
pub fn is_decimal_int_format(&self) -> bool
Returns true if this format spec produces a decimal int representation
subject to sys.get_int_max_str_digits() (no spec, ‘d’, or ‘n’).
Binary bases (‘b’, ‘o’, ‘x’, ‘X’) are exempt per CPython. ‘N’ is rejected
later in format_int as UnknownFormatCode, so it is not included here.
Sourcepub fn format_int_locale(
&self,
num: &BigInt,
locale: &LocaleInfo,
) -> Result<String, FormatSpecError>
pub fn format_int_locale( &self, num: &BigInt, locale: &LocaleInfo, ) -> Result<String, FormatSpecError>
Format an integer with locale-aware ‘n’ format.
Sourcepub fn format_float_locale(
&self,
num: f64,
locale: &LocaleInfo,
) -> Result<String, FormatSpecError>
pub fn format_float_locale( &self, num: f64, locale: &LocaleInfo, ) -> Result<String, FormatSpecError>
Format a float with locale-aware ‘n’ format.
Sourcepub fn format_complex_locale(
&self,
num: &Complex64,
locale: &LocaleInfo,
) -> Result<String, FormatSpecError>
pub fn format_complex_locale( &self, num: &Complex64, locale: &LocaleInfo, ) -> Result<String, FormatSpecError>
Format a complex number with locale-aware ‘n’ format.
pub fn format_bool(&self, input: bool) -> Result<String, FormatSpecError>
pub fn format_float(&self, num: f64) -> Result<String, FormatSpecError>
pub fn format_int(&self, num: &BigInt) -> Result<String, FormatSpecError>
pub fn format_string<T>(&self, s: &T) -> Result<String, FormatSpecError>
pub fn format_complex(&self, num: &Complex64) -> Result<String, FormatSpecError>