pub struct LinkedList<L: Link> { /* private fields */ }Expand description
An intrusive linked list.
Currently, the list is not emptied on drop. It is the caller’s responsibility to ensure the list is empty before dropping it.
Implementations
Sourceimpl<L: Link> LinkedList<L>
impl<L: Link> LinkedList<L>
Sourcepub fn push_front(&mut self, val: L::Handle)
pub fn push_front(&mut self, val: L::Handle)
Adds an element first in the list.
Sourcepub fn pop_front(&mut self) -> Option<L::Handle>
pub fn pop_front(&mut self) -> Option<L::Handle>
Removes the first element from the list and returns it, or None if empty.
Sourcepub unsafe fn remove(&mut self, node: NonNull<L::Target>) -> Option<L::Handle>
pub unsafe fn remove(&mut self, node: NonNull<L::Target>) -> Option<L::Handle>
Removes the specified node from the list
Safety
The caller must ensure that node is currently contained by
self or not contained by any other list.
pub fn iter(&self) -> impl Iterator<Item = &L::Target>
Sourceimpl<L: Link> LinkedList<L>
impl<L: Link> LinkedList<L>
pub const fn drain_filter<F>(&mut self, filter: F) -> DrainFilter<'_, L, F> ⓘ