pub enum TryLockThreadError {
Other,
Current,
}Variants
Other
Failed to lock because mutex was already locked on another thread.
Current
Failed to lock because mutex was already locked on current thread.