Module refcount

Module refcount 

Structs

RefCount
Reference count using state layout with LEAKED support.

Functions

flush_deferred_drops
Flush all deferred drop operations. This is automatically called when exiting a deferred context.
try_defer_drop
Try to defer a drop-related operation. If inside a deferred context, the operation is queued. Otherwise, it executes immediately.
with_deferred_drops
Execute a function within a deferred drop context. Any calls to try_defer_drop within this context will be queued and executed when the context exits (even on panic).