A crate to hold types and functions common to all rustpython components.
Re-exports
pub use rustpython_wtf8 as wtf8;
Modules
- atomic
- borrow
- boxvec
- An unresizable vector backed by a
Box<[T]> - cformat
- Implementation of Printf-Style string formatting as per the Python Docs.
- encodings
- float_
ops - format
- hash
- int
- linked_
list - This module is modified from tokio::util::linked_list: https://github.com/tokio-rs/tokio/blob/master/tokio/src/util/linked_list.rs Tokio is licensed under the MIT license:
- lock
- A module containing
lock_api-based lock types that are or are notSend + Syncdepending on whether thethreadingfeature of this module is enabled. - rand
- rc
- refcount
- static_
cell - str
- vendored
- wtf8_
index - Random access into a WTF-8 buffer.
Macros
- ascii
- Creates an
AsciiStrfrom a string literal, throwing a compile error if the literal isn’t actually ascii. - static_
cell