Module refcount
rustpython_
common
0.5.0
Module refcount
Module Items
Structs
Functions
In crate rustpython_
common
rustpython_common
Module
refcount
Structs

RefCount
Reference count using state layout with LEAKED support.
Functions

flush_
deferred_
drops
Flush all deferred drop operations. This is automatically called when exiting a deferred context.
try_
defer_
drop
Try to defer a drop-related operation. If inside a deferred context, the operation is queued. Otherwise, it executes immediately.
with_
deferred_
drops
Execute a function within a deferred drop context. Any calls to
try_defer_drop
within this context will be queued and executed when the context exits (even on panic).