Module str

Module str 

Re-exports

pub use ascii;

Modules

levenshtein

Macros

ascii
Creates an AsciiStr from a string literal, throwing a compile error if the literal isn’t actually ascii.

Structs

StrData
UnicodeEscapeCodepoint

Enums

PyKindStr
StrKind
Utf8 + state.ascii (+ PyUnicode_Kind in future)

Traits

DeduceStrKind

Functions

char_range_end
char_to_decimal
codepoint_range_end
expandtabs
Replace all tabs in a string with spaces, using the given tab size.
get_chars
get_codepoints
to_ascii
Convert a string to ascii compatible, escaping unicode-s into escape sequences.
try_get_chars
try_get_codepoints
zfill

Type Aliases

wchar_t