Re-exports
pub use ascii;
Modules
Macros
- ascii
- Creates an
AsciiStrfrom a string literal, throwing a compile error if the literal isn’t actually ascii.
Structs
Enums
Traits
Functions
- char_
range_ end - char_
to_ decimal - codepoint_
range_ end - expandtabs
- Replace all tabs in a string with spaces, using the given tab size.
- get_
chars - get_
codepoints - to_
ascii - Convert a string to ascii compatible, escaping unicode-s into escape sequences.
- try_
get_ chars - try_
get_ codepoints - zfill